@@ -15,7 +15,7 @@
 %%
 %% The code has been modified and improved by ProcessOne.
 %%
-%% Copyright 2007-2019   ProcessOne
+%% Copyright 2007-2020   ProcessOne
 %%
 %%  The change adds the following features:
 %%   - You can send exit(priority_shutdown) to the p1_fsm process to
@@ -828,7 +828,7 @@ format_status(Opt, StatusData) ->
 		      Name
 	      end,
     Header = lists:concat(["Status for state machine ", NameTag]),
-    Log = sys:get_debug(log, Debug, []),
+    Log = sys_get_debug(log, Debug, []),
     Specfic =
 	case erlang:function_exported(Mod, format_status, 2) of
 	    true ->
@@ -846,6 +846,12 @@ format_status(Opt, StatusData) ->
 	     {"StateName", StateName}]} |
      Specfic].
 
+-ifdef(USE_OLD_SYS_GET_DEBUG).
+sys_get_debug(Item, Debug, Default) -> sys:get_debug(Item, Debug, Default).
+-else.
+sys_get_debug(log, Debug, _Default) -> sys:get_log(Debug).
+-endif.
+
 %%-----------------------------------------------------------------
 %% Resources limit management
 %%-----------------------------------------------------------------
