@@ -5,7 +5,7 @@
 %%% Created : 29 Jul 2010 by Emilio Bustos <ebustos@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2019 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -273,7 +273,7 @@ get(URL, Hdrs) -> request(get, URL, Hdrs).
 -spec post(string(), string()) -> result().
 post(URL, Body) ->
     request(post, URL,
-	    [{<<"content-type">>, <<"x-www-form-urlencoded">>}],
+	    [{"content-type", "x-www-form-urlencoded"}],
 	    Body).
 
 %% @spec (URL, Hdrs, RequestBody) -> Result
